==> ant-design-vue-4.0.8.jar: META-INF/resources/webjars/ant-design-vue/4.0.8/lib/transfer/ListItem.d.ts <==
import type { ExtractPropTypes } from 'vue';
export declare const transferListItemProps: {
    renderedText: import("vue-types").VueTypeValidableDef<any>;
    renderedEl: import("vue-types").VueTypeValidableDef<any>;
    item: import("vue-types").VueTypeValidableDef<any>;
    checked: {
        type: BooleanConstructor;
        default: boolean;
    };
    prefixCls: StringConstructor;
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    showRemove: {
        type: BooleanConstructor;
        default: boolean;
    };
    onClick: FunctionConstructor;
    onRemove: FunctionConstructor;
};
export type TransferListItemProps = Partial<ExtractPropTypes<typeof transferListItemProps>>;
declare const _default: import("vue").DefineComponent<{
    renderedText: import("vue-types").VueTypeValidableDef<any>;
    renderedEl: import("vue-types").VueTypeValidableDef<any>;
    item: import("vue-types").VueTypeValidableDef<any>;
    checked: {
        type: BooleanConstructor;
        default: boolean;
    };
    prefixCls: StringConstructor;
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    showRemove: {
        type: BooleanConstructor;
        default: boolean;
    };
    onClick: FunctionConstructor;
    onRemove: FunctionConstructor;
}, () => import("vue/jsx-runtime").JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, ("click" | "remove")[], "click" | "remove", import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<ExtractPropTypes<{
    renderedText: import("vue-types").VueTypeValidableDef<any>;
    renderedEl: import("vue-types").VueTypeValidableDef<any>;
    item: import("vue-types").VueTypeValidableDef<any>;
    checked: {
        type: BooleanConstructor;
        default: boolean;
    };
    prefixCls: StringConstructor;
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    showRemove: {
        type: BooleanConstructor;
        default: boolean;
    };
    onClick: FunctionConstructor;
    onRemove: FunctionConstructor;
}>> & {
    onClick?: (...args: any[]) => any;
    onRemove?: (...args: any[]) => any;
}, {
    disabled: boolean;
    checked: boolean;
    showRemove: boolean;
}, {}>;
export default _default;

==> ant-design-vue-4.2.4.jar: META-INF/resources/webjars/ant-design-vue/4.2.4/lib/transfer/ListItem.d.ts <==
import type { ExtractPropTypes } from 'vue';
export declare const transferListItemProps: {
    renderedText: import("vue-types").VueTypeValidableDef<any>;
    renderedEl: import("vue-types").VueTypeValidableDef<any>;
    item: import("vue-types").VueTypeValidableDef<any>;
    checked: {
        type: BooleanConstructor;
        default: boolean;
    };
    prefixCls: StringConstructor;
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    showRemove: {
        type: BooleanConstructor;
        default: boolean;
    };
    onClick: FunctionConstructor;
    onRemove: FunctionConstructor;
};
export type TransferListItemProps = Partial<ExtractPropTypes<typeof transferListItemProps>>;
declare const _default: import("vue").DefineComponent<{
    renderedText: import("vue-types").VueTypeValidableDef<any>;
    renderedEl: import("vue-types").VueTypeValidableDef<any>;
    item: import("vue-types").VueTypeValidableDef<any>;
    checked: {
        type: BooleanConstructor;
        default: boolean;
    };
    prefixCls: StringConstructor;
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    showRemove: {
        type: BooleanConstructor;
        default: boolean;
    };
    onClick: FunctionConstructor;
    onRemove: FunctionConstructor;
}, () => import("vue/jsx-runtime").JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, ("click" | "remove")[], "click" | "remove", import("vue").PublicProps, Readonly<ExtractPropTypes<{
    renderedText: import("vue-types").VueTypeValidableDef<any>;
    renderedEl: import("vue-types").VueTypeValidableDef<any>;
    item: import("vue-types").VueTypeValidableDef<any>;
    checked: {
        type: BooleanConstructor;
        default: boolean;
    };
    prefixCls: StringConstructor;
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    showRemove: {
        type: BooleanConstructor;
        default: boolean;
    };
    onClick: FunctionConstructor;
    onRemove: FunctionConstructor;
}>> & {
    onClick?: (...args: any[]) => any;
    onRemove?: (...args: any[]) => any;
}, {
    disabled: boolean;
    checked: boolean;
    showRemove: boolean;
}, {}>;
export default _default;
